aboutsummaryrefslogtreecommitdiffhomepage
path: root/container/path_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'container/path_test.go')
-rw-r--r--container/path_test.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/container/path_test.go b/container/path_test.go
index 746e70fe..5af4c821 100644
--- a/container/path_test.go
+++ b/container/path_test.go
@@ -10,6 +10,7 @@ import (
"testing"
"unsafe"
+ "hakurei.app/container/check"
"hakurei.app/container/vfs"
)
@@ -49,8 +50,8 @@ func TestToHost(t *testing.T) {
}
}
-// InternalToHostOvlEscape exports toHost passed to EscapeOverlayDataSegment.
-func InternalToHostOvlEscape(s string) string { return EscapeOverlayDataSegment(toHost(s)) }
+// InternalToHostOvlEscape exports toHost passed to [check.EscapeOverlayDataSegment].
+func InternalToHostOvlEscape(s string) string { return check.EscapeOverlayDataSegment(toHost(s)) }
func TestCreateFile(t *testing.T) {
t.Run("nonexistent", func(t *testing.T) {